==> zio-aws-s3control_2.13-5.17.124.3-sources.jar: zio/aws/s3control/model/Exclude.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.s3control.model.primitives.{S3AWSRegion, S3BucketArnString}
import scala.jdk.CollectionConverters._
final case class Exclude(
    buckets: Option[Iterable[S3BucketArnString]] = None,
    regions: Option[Iterable[S3AWSRegion]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.Exclude = {
    import Exclude.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.Exclude
      .builder()
      .optionallyWith(
        buckets.map(value =>
          value.map { item =>
            S3BucketArnString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.buckets)
      .optionallyWith(
        regions.map(value =>
          value.map { item =>
            S3AWSRegion.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.regions)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.Exclude.ReadOnly =
    zio.aws.s3control.model.Exclude.wrap(buildAwsValue())
}
object Exclude {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.s3control.model.Exclude] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.Exclude = zio.aws.s3control.model
      .Exclude(buckets.map(value => value), regions.map(value => value))
    def buckets: Option[List[S3BucketArnString]]
    def regions: Option[List[S3AWSRegion]]
    def getBuckets: ZIO[Any, AwsError, List[S3BucketArnString]] =
      AwsError.unwrapOptionField("buckets", buckets)
    def getRegions: ZIO[Any, AwsError, List[S3AWSRegion]] =
      AwsError.unwrapOptionField("regions", regions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.Exclude
  ) extends zio.aws.s3control.model.Exclude.ReadOnly {
    override val buckets: Option[List[S3BucketArnString]] = scala
      .Option(impl.buckets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.s3control.model.primitives.S3BucketArnString(item)
        }.toList
      )
    override val regions: Option[List[S3AWSRegion]] = scala
      .Option(impl.regions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.s3control.model.primitives.S3AWSRegion(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.Exclude
  ): zio.aws.s3control.model.Exclude.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3control_2.13-5.19.7.6-sources.jar: zio/aws/s3control/model/Exclude.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.s3control.model.primitives.{S3AWSRegion, S3BucketArnString}
import scala.jdk.CollectionConverters._
final case class Exclude(
    buckets: Optional[Iterable[S3BucketArnString]] = Optional.Absent,
    regions: Optional[Iterable[S3AWSRegion]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.Exclude = {
    import Exclude.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.Exclude
      .builder()
      .optionallyWith(
        buckets.map(value =>
          value.map { item =>
            S3BucketArnString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.buckets)
      .optionallyWith(
        regions.map(value =>
          value.map { item =>
            S3AWSRegion.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.regions)
      .build()
  }
  def asReadOnly: zio.aws.s3control.model.Exclude.ReadOnly =
    zio.aws.s3control.model.Exclude.wrap(buildAwsValue())
}
object Exclude {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.s3control.model.Exclude] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3control.model.Exclude = zio.aws.s3control.model
      .Exclude(buckets.map(value => value), regions.map(value => value))
    def buckets: Optional[List[S3BucketArnString]]
    def regions: Optional[List[S3AWSRegion]]
    def getBuckets: ZIO[Any, AwsError, List[S3BucketArnString]] =
      AwsError.unwrapOptionField("buckets", buckets)
    def getRegions: ZIO[Any, AwsError, List[S3AWSRegion]] =
      AwsError.unwrapOptionField("regions", regions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.Exclude
  ) extends zio.aws.s3control.model.Exclude.ReadOnly {
    override val buckets: Optional[List[S3BucketArnString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.buckets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.s3control.model.primitives.S3BucketArnString(item)
          }.toList
        )
    override val regions: Optional[List[S3AWSRegion]] = zio.aws.core.internal
      .optionalFromNullable(impl.regions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.s3control.model.primitives.S3AWSRegion(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.Exclude
  ): zio.aws.s3control.model.Exclude.ReadOnly = new Wrapper(impl)
}
